$$V(h(y_0)-h(\mu_0))=V(h(y_0))+V(h(\mu_0))$$
is used to compute a prediction interval. The prediction variance consists of a component due to the variance of having a single observation and a prediction variance.
algo.farrington.threshold(pred,phi,alpha=0.01,skewness.transform="none",y)"none", "1/2", or "2/3".y
together with the median of the predictive distribution.