Learn R Programming

surveillance (version 1.26.1)

twinSIR_cox: Identify Endemic Components in an Intensity Model

Description

The special function cox marks terms in formulae of the functions twinSIR and simEpidata as endemic components, i.e., variables acting multiplicatively on the baseline infection intensity.

Usage

cox(x)

Arguments

x

a variable from the modelled epidata.

Details

Technically, this function is implemented as the identity, function(x) x, and defined as “special” in terms.formula.

See Also

Usage in formulae of functions twinSIR and simEpidata.