"twinstim" Objectsprint and summary methods there
are also some standard extraction methods defined for objects of class
"twinstim": coef, vcov, and logLik. This
also enables the use of, e.g., AIC. The model
summary can be exported to LaTeX by the corresponding
toLatex method.## S3 method for class 'twinstim':
print(x, digits = max(3, getOption("digits") - 3), ...)
## S3 method for class 'twinstim':
summary(object, test.iaf = FALSE,
correlation = FALSE, symbolic.cor = FALSE, ...)## S3 method for class 'twinstim':
coef(object, ...)
## S3 method for class 'twinstim':
vcov(object, ...)
## S3 method for class 'twinstim':
logLik(object, ...)
## S3 method for class 'summary.twinstim':
print(x,
digits = max(3, getOption("digits") - 3), symbolic.cor = x$symbolic.cor,
signif.stars = getOption("show.signif.stars"), ...)
## S3 method for class 'summary.twinstim':
toLatex(object,
digits = max(3, getOption("digits") - 3), align = "rrrrr",
withAIC = TRUE, ...)
"twinstim" or
"summary.twinstim", respectively.signif(). Minimum number of
significant digits to be printed in values.siaf and tiaf.
Because it is often invalid or meaningless to do so, the default is
FALSETRUE, the correlation matrix of the estimated parameters
is returned and printed.TRUE, print the correlations in a symbolic form (see
symnum) rather than as numbers.TRUE, nchar(align) must equal 5.print.summary.twinstim, arguments passed to
printCoefmat.
For all other methods: unused (argument of the generic).print methods return their first argument, invisibly, as
they always should. The coef, vcov, and logLik
methods return the estimated coefficients, the estimated variance-covariance
matrix of the parameters (here, the inverse of the estimate of the
expected Fisher information matrix), and the maximum log-likelihood
value of the model, respectively.
The summary method returns a list containing some summary
statistics of the model, which is nicely printed by the corresponding
print method.
The toLatex method returns a character vector of class
"Latex", each element containing one line of LaTeX code (see
print.Latex).print and summary methods allow the compact or comprehensive
representation of the fitting results, respectively. The former only prints
the original function call, the estimated coefficients and the maximum
log-likelihood value. The latter prints the whole coefficient matrix
with standard errors, z- and p-values (see printCoefmat)
-- separately for the endemic and the epidemic component -- and
additionally the AIC, the number of log-likelihood and score
evaluations, and the runtime. They both append a big