Usage
## S3 method for class 'twinstim':
print(x, digits = max(3, getOption("digits") - 3), ...)
## S3 method for class 'twinstim':
summary(object, test.iaf = FALSE,
correlation = FALSE, symbolic.cor = FALSE, ...)## S3 method for class 'twinstim':
vcov(object, ...)
## S3 method for class 'twinstim':
logLik(object, ...)
## S3 method for class 'summary.twinstim':
print(x,
digits = max(3, getOption("digits") - 3), symbolic.cor = x$symbolic.cor,
signif.stars = getOption("show.signif.stars"), ...)
## S3 method for class 'summary.twinstim':
toLatex(object,
digits = max(3, getOption("digits") - 3), align = "rrrrr",
withAIC = TRUE, ...)
Arguments
x, object
an object of class "twinstim" or
"summary.twinstim", respectively.
digits
integer, used for number formatting with signif(). Minimum number of
significant digits to be printed in values.
test.iaf
logical indicating if the simple Wald z- and p-values
should be calculated for parameters of the interaction functions
siaf and tiaf.
Because it is often invalid or meaningless to do so, the default is
FALSE
correlation
logical. If TRUE, the correlation matrix of the estimated parameters
is returned and printed.
symbolic.cor
logical. If TRUE, print the correlations in a symbolic form (see
symnum) rather than as numbers.
signif.stars
logical. If TRUE, significance
stars are printed for each coefficient.
align
column alignment used for the LaTeX tabular.
nchar(align) must equal 5.
withAIC
logical indicating if the AIC and the log-likelihood of
the model should be included below the table of coefficients in the
LaTeX tabular.
...
For print.summary.twinstim, arguments passed to
printCoefmat.
For all other methods: unused (argument of the generic).